pub struct LevelIndex {
pub byte_offset: u64,
pub byte_length: u64,
pub uncompressed_byte_length: u64,
}Expand description
Offsets dictating the location of a Level within a file.
This is mainly useful for writing or low-level manipulation. Prefer Reader::levels for data access.
Fields
byte_offset: u64Byte offset from the start of the file to this level’s data.
byte_length: u64Byte length of the (possibly supercompressed) level data.
uncompressed_byte_length: u64Byte length after decompression. 0 for BasisLZ.
Implementations